using System.ComponentModel;
using System.Xml.Serialization;

namespace EQIA.EQIDL
{
    [TypeConverter(typeof(SliderDrawTemplateConverter))]
    public partial class SliderDrawTemplate : Class
    {
        #region Members

        private ButtonDrawTemplate myThumb;
        private string myBackground, myEndCapRight, myEndCapLeft;

        #endregion

        #region Properties

        [XmlElement("Thumb", IsNullable = false)]
        [Browsable(true), Description("Template that defines the art for this slider's thumb (the piece that is scrolled to change the slider's value)")]
        [NotifyParentProperty(true)]
        public ButtonDrawTemplate Thumb { get { return myThumb; } set { myThumb = value; } }

        [XmlElement("Background", IsNullable = false)]
        [Browsable(true), Description("Background image for the slider (that the thumb scrolls along)")]
        [NotifyParentProperty(true)]
        public string Background { get { return myBackground; } set { myBackground = value; } }

        [XmlElement("EndCapRight", IsNullable = false)]
        [Browsable(true), Description("Right end cap piece")]
        [NotifyParentProperty(true)]
        public string EndCapRight { get { return myEndCapRight; } set { myEndCapRight = value; } }

        [XmlElement("EndCapLeft", IsNullable = false)]
        [Browsable(true), Description("Left end cap piece")]
        [NotifyParentProperty(true)]
        public string EndCapLeft { get { return myEndCapLeft; } set { myEndCapLeft = value; } }

        #endregion

        #region Creation

        public SliderDrawTemplate()
            : this(null)
        {
        }

        public SliderDrawTemplate(EQInterface eqInterface)
            : base(eqInterface)
        {
        }

        #endregion

        #region Deserialization

        protected override void SetProperties(object obj)
        {
            base.SetProperties(obj);

            SliderDrawTemplate temp_SliderDrawTemplate = obj as SliderDrawTemplate;
            if (temp_SliderDrawTemplate != null)
            {
                Thumb = temp_SliderDrawTemplate.Thumb;
                Background = temp_SliderDrawTemplate.Background;
                EndCapLeft = temp_SliderDrawTemplate.EndCapLeft;
                EndCapRight = temp_SliderDrawTemplate.EndCapRight;
            }
        }

        #endregion
    }

    public class SliderDrawTemplateConverter : ExpandableObjectConverter
    {
        public override object ConvertTo(ITypeDescriptorContext context, System.Globalization.CultureInfo culture, object value, System.Type destinationType)
        {
            return (destinationType == typeof(string)) ? string.Empty : base.ConvertTo(context, culture, value, destinationType);
        }
    }
}
